#!/bin/bash
# Author(s): Guillaume GARDET <guillaume.gardet@opensuse.org>
# Changelog:
# 	* 2013-09-23: Fix openGL ES demo
# 	* 2013-09-12: Add basic USB test (requires an usb stick)
# 	* 2013-09-11: Initial release (audio, video, openGL, openGL ES, network tests and chromebook support)


# Log files
audio_test_log="./audio_test.log"
video_test_log="./video_test.log"
opengl_test_log="./opengl_test.log"
opengles_test_log="./opengles_test.log"
network_test_log="./network_test.log"
usb_test_log="./usb_test.log"

# Test files
audio_test_file="test_audio/0716.wav"
video_test_file="test_video/trailer_400p.ogg"
network_test_addr="http://www.google.com"
network_test_file="index.html"

# Cleanup old log files
rm -rf ./*.log

# Find out what is the current system
cpuinfo_name=$(cat /proc/cpuinfo | grep Hardware)
if [ "$(echo $cpuinfo_name | grep 'Flattened Device Tree')" == "" ]; then
	is_device_tree=0
else
	is_device_tree=1
fi

if [ $is_device_tree ]; then
	dt_compatible_info=$(cat /proc/device-tree/compatible)
fi

if [ "$dt_compatible_info" == "google,snowsamsung,exynos5250" ]; then
	is_chromebook=1
	board_name_short="Chromebook"
else # TODO: add other boards support
	board_name_short="Unknown"
fi
kernel_info=$(uname -rv)

echo "**********************************************************************"
echo "* Detected system: $board_name_short"
echo "* Details:"
echo "*  $cpuinfo_name"
echo "*  $dt_compatible_info"
echo "* Kernel details: $kernel_info"
echo "* openSUSE version: $(cat /etc/SuSE-release | grep openSUSE)"
echo "**********************************************************************"


# Ask which test to run
echo -n "Do you want to run audio test? (y/n)"
read test_audio

echo -n "Do you want to run video test? (y/n)"
read test_video

echo -n "Do you want to run openGL test? (y/n)"
read test_opengl

echo -n "Do you want to run openGL ES test? (y/n)"
read test_opengles

echo -n "Do you want to run network test? (Require an internet connexion) (y/n)"
read test_network

echo -n "Do you want to run USB test? (Require an USB stick) (y/n)"
read test_usb

# Init var
test_results="**********************************************************************\n* RESULTS:\n"


# Audio test with aplay
if [ "$test_audio" == "y" ]; then
	echo "Runing AUDIO test"
	# Check if aplay is installed
	if [ "$(which aplay | grep which)" != "" ]; then
		echo "This test require 'alsa-utils'. Please install it first with:"
		echo "  sudo zypper install alsa-utils"
		exit;
	fi
	echo -n "Listen. I am playing an audio file..." 
	aplay $audio_test_file &> $audio_test_log
	echo "Done."	
	echo -n "Did you hear something?(y,n)"
	read test_audio_result
	if [ "$test_audio_result" == "y" ]; then
		test_results="$test_results*  Audio: passed\n"
	else
		test_results="$test_results*  Audio: FAILED\n"
	fi
else
	test_results="$test_results*  Audio: not tested\n"
fi

# Video test with ffmpeg
if [ "$test_video" == "y" ]; then
	echo "Runing VIDEO test"
	# Check if ffplay is installed
	if [ "$(which ffplay | grep which)" != "" ]; then
		echo "This test require 'ffmpeg'. Please install it first with:"
		echo "  sudo zypper install ffmpeg"
		exit;
	fi
	echo -n "Watch. I am playing a video file..." 
	ffplay $video_test_file  &> $video_test_log&
	sleep 10
	pkill ffplay
	echo "Done."	
	echo -n "Did you see something?(y,n)"
	read test_video_result
	if [ "$test_video_result" == "y" ]; then
		test_results="$test_results*  Video: passed\n"
	else
		test_results="$test_results*  Video: FAILED\n"
	fi
else
	test_results="$test_results*  Video: not tested\n"
fi

# openGL
if [ "$test_opengl" == "y" ]; then
	echo "Runing openGL test"
	# Check if glxgears is installed
	if [ "$(which glxgears | grep which)" != "" ]; then
		echo "This test require 'Mesa-demo-x'. Please install it first with:"
		echo "  sudo zypper install Mesa-demo-x"
		exit;
	fi
	echo -n "Watch. I am playing an openGL demo (glxgears)..." 
	glxgears &> $opengl_test_log&
	sleep 10
	pkill glxgears
	echo "Done."	
	echo -n "Did you see something?(y,n)"
	read test_opengl_result
	if [ "$test_opengl_result" == "y" ]; then
		test_results="$test_results*  openGL: passed ($(glxinfo 2> /dev/null | grep -i renderer))\n"
	else
		test_results="$test_results*  openGL: FAILED ($(glxinfo 2> /dev/null | grep -i renderer))\n"
	fi
else
	test_results="$test_results*  openGL: not tested\n"
fi

# openGL ES
if [ "$test_opengles" == "y" ]; then
	echo "Runing openGL ES test"
	# Check if es2gears_x11 is installed
	if [ "$(LANG='' ls /usr/lib/mesa-demos/egl/opengles2/es2gears_x11 | grep -v 'cannot access')" == "" ]; then
		echo "This test require 'Mesa-demo-egl'. Please install it first with:"
		echo "  sudo zypper install Mesa-demo-egl"
		exit;
	fi
	echo -n "Watch. I am playing an openGL ES demo (es2gears_x11)..." 
	/usr/lib/mesa-demos/egl/opengles2/es2gears_x11 &> $opengles_test_log&
	sleep 10
	pkill es2gears_x11
	echo "Done."	
	echo -n "Did you see something?(y,n)"
	read test_opengles_result
	if [ "$test_opengles_result" == "y" ]; then
		test_results="$test_results*  openGL ES: passed ($(es2_info 2> /dev/null | grep -i renderer))\n"
	else
		test_results="$test_results*  openGL ES: FAILED ($(es2_info 2> /dev/null | grep -i renderer))\n"
	fi
else
	test_results="$test_results*  openGL ES: not tested\n"
fi

# Network
if [ "$test_network" == "y" ]; then
	echo "Runing network test"
	# Check if wget is installed
	if [ "$(which wget | grep which)" != "" ]; then
		echo "This test require 'wget'. Please install it first with:"
		echo "  sudo zypper install wget"
		exit;
	fi
	echo -n "Testing network..."
	wget $network_test_addr/$network_test_file  &> $network_test_log
	echo "Done"
	if [ "$(ls $network_test_file 2> /dev/null)" == "$network_test_file" ]; then
		test_network_result=y
		rm $network_test_file
	else
		test_network_result=n
	fi
	if [ "$test_network_result" == "y" ]; then
		test_results="$test_results*  Network: passed\n"
	else
		test_results="$test_results*  Network: FAILED\n"
	fi
else
	test_results="$test_results*  Network: not tested\n"
fi

# USB
if [ "$test_usb" == "y" ]; then
	echo "Runing USB test"
	# Check if diff is installed
	if [ "$(which diff | grep which)" != "" ]; then
		echo "This test require 'diff'. Please install it first with:"
		echo "  sudo zypper install diffutils"
		exit;
	fi
	ls /dev/ > ./tmp.beforeplug
	echo -n "Please plug your USB stick in a USB port and hit return key when done."
	read
	ls /dev/ > ./tmp.afterplug
	usbdiff=$(diff -pur ./tmp.beforeplug ./tmp.afterplug)
	rm ./tmp.beforeplug ./tmp.afterplug # clean up temp files
	echo $usbdiff &> $usb_test_log
	if [ "$usbdiff" == "" ]; then
		test_usb_result=n
	else
		test_usb_result=y
	fi
	if [ "$test_usb_result" == "y" ]; then
		test_results="$test_results*  USB: passed\n"
	else
		test_results="$test_results*  USB: FAILED\n"
	fi
else
	test_results="$test_results*  USB: not tested\n"
fi


# Display results
echo -e -n "$test_results"
echo "**********************************************************************"
